Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1421)

Unified Diff: content/network/network_context.h

Issue 2968293002: Introduce SystemNetworkContextManager. (Closed)
Patch Set: Response to comments Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/network/DEPS ('k') | content/network/network_context.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/network/network_context.h
diff --git a/content/network/network_context.h b/content/network/network_context.h
index 278923f8ff17d6ce535c929d8ef35bd6bf6d613c..c50fc033244f53f9a63cf1d3788e4aaae171bad6 100644
--- a/content/network/network_context.h
+++ b/content/network/network_context.h
@@ -19,17 +19,25 @@
namespace net {
class URLRequestContext;
+class URLRequestContextBuilder;
}
namespace content {
-class NetworkService;
+class NetworkServiceImpl;
class URLLoaderImpl;
class NetworkContext : public mojom::NetworkContext {
public:
- NetworkContext(NetworkService* network_service,
+ NetworkContext(NetworkServiceImpl* network_service,
mojom::NetworkContextRequest request,
mojom::NetworkContextParamsPtr params);
+
+ // Temporary constructor that allows creating an in-process NetworkContext
+ // with a pre-populated URLRequestContextBuilder.
+ NetworkContext(mojom::NetworkContextRequest request,
+ mojom::NetworkContextParamsPtr params,
+ std::unique_ptr<net::URLRequestContextBuilder> builder);
+
~NetworkContext() override;
CONTENT_EXPORT static std::unique_ptr<NetworkContext> CreateForTesting();
@@ -49,7 +57,7 @@ class NetworkContext : public mojom::NetworkContext {
void HandleViewCacheRequest(const GURL& url,
mojom::URLLoaderClientPtr client) override;
// Called when the associated NetworkService is going away. Guaranteed to
// destroy NetworkContext's URLRequestContext.
void Cleanup();
@@ -59,7 +67,7 @@ class NetworkContext : public mojom::NetworkContext {
// On connection errors the NetworkContext destroys itself.
void OnConnectionError();
- NetworkService* const network_service_;
+ NetworkServiceImpl* const network_service_;
std::unique_ptr<net::URLRequestContext> url_request_context_;
« no previous file with comments | « content/network/DEPS ('k') | content/network/network_context.cc » ('j') | no next file with comments »
@@ -49,7 +57,7 @@ class NetworkContext : public mojom::NetworkContext {
void HandleViewCacheRequest(const GURL& url,
mojom::URLLoaderClientPtr client) override;
- // Called when the associated NetworkService is going away. Guaranteed to
+ // Called when the associated NetworkServiceImpl is going away. Guaranteed to
// destroy NetworkContext's URLRequestContext.
void Cleanup();

Powered by Google App Engine
This is Rietveld 408576698